forwarder

package
v0.0.0-...-55fa497 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

const DefaultNumShards = 16
const GPSOffset = 18000

GPSOffset compensates for the drift between UTC and GPS time

Variables

This section is empty.

Functions

This section is empty.

Types

type Forwarder

type Forwarder struct {
	// contains filtered or unexported fields
}

Forwarder allows communication between devices and gateways. Routing maps are split across shards keyed by device EUI so that concurrent operations on different devices don't contend on the same lock.

func Setup

func Setup() *Forwarder

func (*Forwarder) AddDevice

func (f *Forwarder) AddDevice(d m.InfoDevice)

func (*Forwarder) AddGateway

func (f *Forwarder) AddGateway(g m.InfoGateway)

func (*Forwarder) DeleteDevice

func (f *Forwarder) DeleteDevice(DevEUI lorawan.EUI64)

func (*Forwarder) DeleteGateway

func (f *Forwarder) DeleteGateway(g m.InfoGateway)
func (f *Forwarder) Downlink(data *lorawan.PHYPayload, freq uint32,
	macAddress lorawan.EUI64, tmst *uint32, rawData []byte) bool

func (*Forwarder) Register

func (f *Forwarder) Register(freq uint32, devEUI lorawan.EUI64, rDownlink *dl.ReceivedDownlink)

func (*Forwarder) Reset

func (f *Forwarder) Reset()

func (*Forwarder) UnRegister

func (f *Forwarder) UnRegister(freq uint32, devEUI lorawan.EUI64)

func (*Forwarder) UpdateDevAddr

func (f *Forwarder) UpdateDevAddr(devEUI lorawan.EUI64, devAddr lorawan.DevAddr)

func (*Forwarder) UpdateDevice

func (f *Forwarder) UpdateDevice(d m.InfoDevice)
func (f *Forwarder) Uplink(data pkt.RXPK, DevEUI lorawan.EUI64)

type RoutingShard

type RoutingShard struct {
	// contains filtered or unexported fields
}

Directories

Path Synopsis

Jump to