util

package
v0.0.0-...-55fa497 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	ConnectedPowerSource = 0

	MAXFCNTGAP = uint32(16384)

	PrintBoth = iota
	PrintOnlySocket
	PrintOnlyConsole

	Stopped
	Running

	Normal
	Retransmission
	FPending
	Activation
)

Constants

Variables

This section is empty.

Functions

func CreateConfigDir

func CreateConfigDir(path string) error

CreateConfigDir creates the config directory in the provided path

func CreateConfigFiles

func CreateConfigFiles()

CreateConfigFiles creates the config files in the config directory

func GetConfigDirname

func GetConfigDirname() string

GetConfigDirname returns the field configDirname from the config file

func GetPath

func GetPath() (string, error)

GetPath returns the path of the config directory path, and creates it if it does not exist

func RecoverConfigFile

func RecoverConfigFile(path string, v interface{}) error

RecoverConfigFile reads the data from the file in the path and stores it in the provided interface

func WriteConfigFile

func WriteConfigFile(path string, data []byte) error

WriteConfigFile writes the data to the file in the path

Types

This section is empty.

Jump to