Documentation
¶
Index ¶
- Constants
- type Forwarder
- func (f *Forwarder) AddDevice(d m.InfoDevice)
- func (f *Forwarder) AddGateway(g m.InfoGateway)
- func (f *Forwarder) DeleteDevice(DevEUI lorawan.EUI64)
- func (f *Forwarder) DeleteGateway(g m.InfoGateway)
- func (f *Forwarder) Downlink(data *lorawan.PHYPayload, freq uint32, macAddress lorawan.EUI64, tmst *uint32, ...) bool
- func (f *Forwarder) Register(freq uint32, devEUI lorawan.EUI64, rDownlink *dl.ReceivedDownlink)
- func (f *Forwarder) Reset()
- func (f *Forwarder) UnRegister(freq uint32, devEUI lorawan.EUI64)
- func (f *Forwarder) UpdateDevAddr(devEUI lorawan.EUI64, devAddr lorawan.DevAddr)
- func (f *Forwarder) UpdateDevice(d m.InfoDevice)
- func (f *Forwarder) Uplink(data pkt.RXPK, DevEUI lorawan.EUI64)
- type RoutingShard
Constants ¶
const DefaultNumShards = 16
const GPSOffset = 18000
GPSOffset compensates for the drift between UTC and GPS time
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Forwarder ¶
type Forwarder struct {
// contains filtered or unexported fields
}
Forwarder allows communication between devices and gateways. Routing maps are split across shards keyed by device EUI so that concurrent operations on different devices don't contend on the same lock.
func (*Forwarder) AddDevice ¶
func (f *Forwarder) AddDevice(d m.InfoDevice)
func (*Forwarder) AddGateway ¶
func (f *Forwarder) AddGateway(g m.InfoGateway)
func (*Forwarder) DeleteDevice ¶
func (*Forwarder) DeleteGateway ¶
func (f *Forwarder) DeleteGateway(g m.InfoGateway)
func (*Forwarder) UpdateDevAddr ¶
func (*Forwarder) UpdateDevice ¶
func (f *Forwarder) UpdateDevice(d m.InfoDevice)
type RoutingShard ¶
type RoutingShard struct {
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.