Documentation
¶
Index ¶
Constants ¶
const ( ConnectedPowerSource = 0 MAXFCNTGAP = uint32(16384) PrintBoth = iota PrintOnlySocket PrintOnlyConsole Stopped Running Normal Retransmission FPending Activation )
Constants
Variables ¶
This section is empty.
Functions ¶
func CreateConfigDir ¶
CreateConfigDir creates the config directory in the provided path
func CreateConfigFiles ¶
func CreateConfigFiles()
CreateConfigFiles creates the config files in the config directory
func GetConfigDirname ¶
func GetConfigDirname() string
GetConfigDirname returns the field configDirname from the config file
func GetPath ¶
GetPath returns the path of the config directory path, and creates it if it does not exist
func RecoverConfigFile ¶
RecoverConfigFile reads the data from the file in the path and stores it in the provided interface
func WriteConfigFile ¶
WriteConfigFile writes the data to the file in the path
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.